sys = require "luci.sys"                                           
ut = require "luci.util" 

--------------------------------------------------------------------------------------------------------
m=Map("iec101-to-104","IEC 101 to IEC104 Converter")

section_global = m:section(TypedSection, "global", translate("Enable/ Disable"))
section_global.anonymous = true
section_global.addremove = false
section_global.name = "global"

option_enabled = section_global:option(Flag, "enabled", translate("Enabled"),
		translate("Enable IEC 101 to 104"))
option_enabled.rmempty=false
option_enabled.default="1"

s = m:section(TypedSection, "configuration101", "IEC 101 configuration")
s.anonymous = true

serial_port = s:option(Value, "serial_port", translate("Serial Port"))
serial_port.default = "/dev/ttyS0"

speed = s:option(ListValue, "baud", translate("Baud Rate"))
speed:value("300", translate("300"))
speed:value("600", translate("600"))
speed:value("1200", translate("1200"))
speed:value("2400", translate("2400"))
speed:value("4800", translate("4800"))
speed:value("9600", translate("9600"))
speed:value("19200", translate("19200"))
speed:value("38400", translate("38400"))
speed:value("19200", translate("19200"))
speed:value("57600", translate("57600"))
speed.default = "9600"

parity = s:option(ListValue, "parity", translate("Parity"))
parity:value("N", translate("None"))
parity:value("E", translate("Even"))
parity:value("O", translate("Odd"))
parity.default = "E"

databits = s:option(ListValue, "data_bit", translate("Data bits"))
databits:value("6", "6")
databits:value("7", "7")
databits:value("8", "8")
databits.default = "8"

stopbits = s:option(ListValue, "stop_bit", translate("Stop bits"))
stopbits:value("1", "1")
stopbits:value("2", "2")
stopbits.default = "1"

operation_mode = s:option(ListValue,"operation_mode",translate("Link Transmission Procedure"))
operation_mode:value("unbalanced","Unbalanced")
operation_mode:value("balanced","Balanced")
operation_mode.default = "balanced"

iec101_master_addr = s:option(Value,"iec101_master_addr",translate("ASDU Address"))
iec101_master_addr.datatype    = "and(min(1),uinteger)"
iec101_master_addr.placeholder = "0-65535"
iec101_master_addr.default = "1"
iec101_master_addr:depends("operation_mode", "balanced")

iec101_slave_addr = s:option(Value,"iec101_slave_addr",translate("Link Address"))
iec101_slave_addr.datatype    = "and(min(0),uinteger)"
iec101_slave_addr.placeholder = "0-65535"
iec101_slave_addr.default = "1"

timeoutRepeat = s:option(Value, "timeoutRepeat", "Timeout Repeat", translate("Timeout for repeated message transmission when no ACK received in milliseconds"))
timeoutRepeat.datatype = "integer"
timeoutRepeat.default = "1000"
timeoutRepeat:depends("connection", "rtu")

timeoutForAck = s:option(Value, "timeoutForAck", "Timeout For Ack", translate("Timeout for link layer ACK in milliseconds "))
timeoutForAck.datatype = "integer"
timeoutForAck.default = "200"
timeoutForAck:depends("connection", "rtu")

useSingleCharACK = s:option(ListValue, "useSingleCharACK", "Use Single Char ACK", translate("Use single char ACK or RESP_NO_USER_DATA "))
useSingleCharACK:value("0", "No")
useSingleCharACK:value("1", "Yes")
useSingleCharACK.default = "0"
useSingleCharACK:depends("connection", "rtu")

oa = s:option(Value,"oa",translate("OA"))
oa.datatype    = "and(min(0),uinteger)"
oa.placeholder = "0-65535"
oa.default = "0"

sizeof_cot = s:option(ListValue,"sizeof_cot",translate("COT size"))
sizeof_cot:value("1","One Octet")
sizeof_cot:value("2","Two Octets")
sizeof_cot.default = "2"

sizeof_ca = s:option(ListValue,"sizeof_ca",translate("ASDU Address size"))
sizeof_ca:value("1","One Octet")
sizeof_ca:value("2","Two Octets")
sizeof_ca.default = "2"

sizeof_ioa = s:option(ListValue,"sizeof_ioa",translate("IOA address size"))
sizeof_ioa:value("1","One Octet")
sizeof_ioa:value("2","Two Octets")
sizeof_ioa:value("3","Three Octets")
sizeof_ioa.default = "3"

addressLength = s:option(ListValue,"addressLength",translate("Address Length"))
addressLength:value("0","Not Present")
addressLength:value("1","One Octet")
addressLength:value("2","Two Octets")
addressLength.default = "1"

max_asdu_length = s:option(Value,"max_asdu_length",translate("Max ASDU Length"))
max_asdu_length.datatype    = "and(min(1),uinteger)"
max_asdu_length.placeholder = "0-512"
max_asdu_length.default = "249"


s2 = m:section(TypedSection,"configuration104",translate("IEC 104 Master Configuration"))
s2.anonymous =true

no_of_connections = s2:option(Value, "no_of_connections", "Number Of IEC104-Master Connections", translate("Maximum number of simultaneous IEC104-Master connections"))
no_of_connections.datatype = "integer"
no_of_connections.default = "1"

t0= s2:option(Value,"t0",translate("Time out T0"))
t0.datatype    = "and(min(1),uinteger)"
t0.placeholder = "0-65535"
t0.default = "15000"

t1= s2:option(Value,"t1",translate("Time out T1"))
t1.datatype    = "and(min(1),uinteger)"                 
t1.placeholder = "0-65535"              
t1.default = "15000"

t2= s2:option(Value,"t2",translate("Time out T2"))
t2.datatype    = "and(min(1),uinteger)"                 
t2.placeholder = "0-65535"              
t2.default = "2000"

t3= s2:option(Value,"t3",translate("Time out T3"))
t3.datatype    = "and(min(1),uinteger)"                 
t3.placeholder = "0-65535"              
t3.default = "20000"

k= s2:option(Value,"k",translate("K"))
k.datatype    = "and(min(1),uinteger)"
k.placeholder = "0-65535"
k.default = "2000"

w= s2:option(Value,"w",translate("W"))
w.datatype    = "and(min(1),uinteger)"
w.placeholder = "0-65535"
w.default = "2000"

oa_104 = s2:option(Value,"oa",translate("OA"))
oa_104.datatype    = "and(min(0),uinteger)"
oa_104.placeholder = "0-65535"
oa_104.default = "0"

sizeof_cot_104 = s2:option(ListValue,"sizeof_cot",translate("COT size"))
sizeof_cot_104:value("1","One Octet")
sizeof_cot_104:value("2","Two Octets")
sizeof_cot_104.default = "2"

sizeof_ca_104 = s2:option(ListValue,"sizeof_ca",translate("ASDU Address size"))
sizeof_ca_104:value("1","One Octet")
sizeof_ca_104:value("2","Two Octets")
sizeof_ca_104.default = "2"

sizeof_ioa_104 = s2:option(ListValue,"sizeof_ioa",translate("IOA address size"))
sizeof_ioa_104:value("1","One Octet")
sizeof_ioa_104:value("2","Two Octets")
sizeof_ioa_104:value("3","Three Octets")
sizeof_ioa_104.default = "3"

max_asdu_length_104 = s2:option(Value,"max_asdu_length",translate("Max ASDU Length"))
max_asdu_length_104.datatype    = "and(min(1),uinteger)"
max_asdu_length_104.placeholder = "0-512"
max_asdu_length_104.default = "249"



return m
